@@ -9,8 +9,8 @@ no warnings qw(experimental::lexical_subs);
 
 package Spreadsheet::Edit::IO;
 $Spreadsheet::Edit::IO::VERSION = 999.999; # over-ridden in released dist.
-our $VERSION = '3.022'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-06-08'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '3.023'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-06-09'; # DATE from Dist::Zilla::Plugin::OurDate
 
 # This module is derived from the old never-released Text:CSV::Spreadsheet
 
@@ -27,12 +27,15 @@ our @EXPORT_OK = qw/@sane_CSV_read_options @sane_CSV_write_options/;
 use version ();
 use Carp;
 
+use File::Find ();
 use File::Copy ();
 use File::Copy::Recursive ();
+use File::Glob qw/bsd_glob/;
 
 use Path::Tiny qw/path/;
 
 # Path::Tiny OBVIATES NEED for many but we still need this
+use File::Spec ();
 use File::Spec::Functions qw/devnull tmpdir rootdir catdir catfile/;
 
 # Still sometimes convenient...
